@@ -828,8 +828,7 @@ def book_alternative_names() -> dict[bible.Book, list[str]]:
 
 @pytest.fixture()
 def book_alternative_names_verbum() -> dict[bible.Book, list[str]]:
-    """
-    Return the abbreviations supported by verbum.
+    """Return the abbreviations supported by verbum.
 
     https://support.verbum.com/hc/en-us/articles/360021231612-Bible-Book-Abbreviations
     """
